@@ -2,7 +2,7 @@
 package Net::Pcap::Easy;
 
 use strict;
-#use warnings;
+no warnings;
 
 use Carp;
 use Socket;
@@ -16,7 +16,7 @@ use NetPacket::UDP;
 use NetPacket::IGMP;
 use NetPacket::ICMP qw(:types);
 
-our $VERSION     = "1.4207";
+our $VERSION     = "1.4209";
 our $MIN_SNAPLEN = 256;
 our $DEFAULT_PPL = 32;
 
@@ -78,8 +78,8 @@ sub new {
             my $ppl = $this->{packets_per_loop};
                $ppl = $this->{packets_per_loop} = $DEFAULT_PPL unless defined $ppl and $ppl > 0;
 
-            my $ttl = $this->{timeout_in_ms} || 0;
-               $ttl = 0 if $ttl < 0;
+            my $ttl = $this->{timeout_in_ms} || 250;
+               $ttl = 250 if $ttl < 0;
 
             my $snaplen = $this->{bytes_to_capture} || 1024;
                $snaplen = $MIN_SNAPLEN unless $snaplen >= 256;
